﻿#region Using directives
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.ComponentModel;
using System.Windows.Controls;
using Telerik.Windows.Controls;
using System.Windows.Data; 
#endregion

namespace BC.DataFilterExtensions
{
    /// <summary>
    /// EditorTemplateSelector
    /// </summary>
    public class EnumEditorTemplateSelector : DataTemplateSelector
    {
        /// <summary>
        /// When overridden in a derived class, returns a <see cref="T:System.Windows.DataTemplate"/> based on custom logic.
        /// </summary>
        /// <param name="item">The data object for which to select the template.</param>
        /// <param name="container">The data-bound object.</param>
        /// <returns>
        /// Returns a <see cref="T:System.Windows.DataTemplate"/> or null. The default value is null.
        /// </returns>
        public override DataTemplate SelectTemplate(object item, DependencyObject container)
        {
            ItemPropertyInfo info = (ItemPropertyInfo)item;

            // Create RadComboBox for Enums
            if (info.PropertyType.IsEnum)
            {
                // Create template
                DataTemplate template = new DataTemplate();

                // Create FrameworkElementFactory instance
                FrameworkElementFactory fef = new FrameworkElementFactory(typeof(RadComboBox));

                // Create value binding
                Binding binding = new Binding("Value");
                binding.Mode = BindingMode.TwoWay;
                binding.FallbackValue = Activator.CreateInstance(info.PropertyType);

                // Set binding
                fef.SetBinding(RadComboBox.SelectedValueProperty, binding);

                // Set visual tree
                template.VisualTree = fef;

                // Seal template
                template.Seal();

                return template;
            }
            else
            {
                // Get default template
                return base.SelectTemplate(item, container);
            }
        }
    }
}
