﻿#region Using directives
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Windows;
using System.Windows.Navigation;
using System.Xml.Linq;
using BC.DataFilterExtensions;
using Telerik.Windows.Controls;
using Telerik.Windows.Data;
#endregion

namespace BC.DataFilterTest
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="MainWindow"/> class.
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            List<ItemPropertyInfo> itemPropertyInfos = new List<ItemPropertyInfo>();

            // Set ItemPropertyInfos manually
            itemPropertyInfos.Add(new ItemPropertyInfo("Value", typeof(int), typeof(TestClass1).GetProperty("Value")));
            itemPropertyInfos.Add(new ItemPropertyInfo("PositionEnum", typeof(JournalEntryPosition), typeof(TestClass1).GetProperty("PositionEnum")));
            itemPropertyInfos.Add(new ItemPropertyInfo("Name", typeof(string), typeof(TestClass1).GetProperty("Name")));
            itemPropertyInfos.Add(new ItemPropertyInfo("TestClass2.IsVisible", typeof(bool), typeof(TestClass2).GetProperty("IsVisible")));
            itemPropertyInfos.Add(new ItemPropertyInfo("TestClass2.Description", typeof(string), typeof(TestClass2).GetProperty("Description")));

            this._dataFilter.ItemProperties = itemPropertyInfos.ToArray();

            // Create instance of UnboundRadDataFilterHelper
            this.UnboundRadDataFilterHelper = new UnboundRadDataFilterHelper<TestClass1>(this._dataFilter);

            // Create test data
            this.UnboundRadDataFilterHelper.Source = new TestClass1[]
            {
                new TestClass1() { Value=1, PositionEnum = JournalEntryPosition.Current, Name = "John", TestClass2 = new TestClass2() { IsVisible = true, Description = "Something" } },
                new TestClass1() { Value=2, PositionEnum = JournalEntryPosition.Forward, Name = "Diana", TestClass2 = new TestClass2() { IsVisible = true, Description = "Nothing" } },
                new TestClass1() { Value=3, PositionEnum = JournalEntryPosition.Current, Name = "Adam", TestClass2 = new TestClass2() { IsVisible = false, Description = "All" } },
                new TestClass1() { Value=4, PositionEnum = JournalEntryPosition.Back, Name = "Julia", TestClass2 = new TestClass2() { IsVisible = true, Description = "Zero" } },
                new TestClass1() { Value=5, PositionEnum = JournalEntryPosition.Current, Name = "Thomas", TestClass2 = new TestClass2() { IsVisible = false, Description = "Dummy" } },
                new TestClass1() { Value=6, PositionEnum = JournalEntryPosition.Back, Name = "Adam", TestClass2 = new TestClass2() { IsVisible = false, Description = "42" } }
            };

            // Set this instance as "viewmodel"
            this.DataContext = this;

            // Load filter as XML from ApplicationSettings
            this.UnboundRadDataFilterHelper.FilterXml = Properties.Settings.Default.FilterXml;
        }

        /// <summary>
        /// Instance of UnboundRadDataFilterHelper
        /// </summary>
        public UnboundRadDataFilterHelper<TestClass1> UnboundRadDataFilterHelper { get; private set; }

        /// <summary>
        /// Raises the <see cref="E:System.Windows.Window.Closed"/> event.
        /// </summary>
        /// <param name="e">An <see cref="T:System.EventArgs"/> that contains the event data.</param>
        protected override void OnClosed(EventArgs e)
        {
            base.OnClosed(e);

            // Save current Filter as XML in Applicationsettings
            Properties.Settings.Default.FilterXml = this.UnboundRadDataFilterHelper.FilterXml;
            Properties.Settings.Default.Save();

            // Free resources of UnboundRadDataFilterHelper
            this.UnboundRadDataFilterHelper.Dispose();
        }

        /// <summary>
        /// Handles the Click event of the _buttonCopy control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.Windows.RoutedEventArgs"/> instance containing the event data.</param>
        private void _buttonCopy_Click(object sender, RoutedEventArgs e)
        {
            // Copy XML to clipboard
            Clipboard.SetText(this.UnboundRadDataFilterHelper.FilterXml);
        }

        /// <summary>
        /// Handles the Click event of the _buttonPaste control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.Windows.RoutedEventArgs"/> instance containing the event data.</param>
        private void _buttonPaste_Click(object sender, RoutedEventArgs e)
        {   
            // Paste XML from clipboard
            this.UnboundRadDataFilterHelper.FilterXml = Clipboard.GetText();
        }

        /// <summary>
        /// Handles the Click event of the _buttonClear control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.Windows.RoutedEventArgs"/> instance containing the event data.</param>
        private void _buttonClear_Click(object sender, RoutedEventArgs e)
        {
            // Clear filter
            this.UnboundRadDataFilterHelper.FilterXml = string.Empty;
        }
    }
}
